/***************************************************************************
 *                                                                         *
 *                            LibQNotify                                   *
 *                                                                         *
 *            Copyright (C) 2006 Holger Macht <holger@homac.de>            *
 *                                                                         *
 *                 Author: Holger Macht <holger@homac.de>                  *
 *                                                                         *
 * This program is free software; you can redistribute it and/or modify it *
 * under the terms of the GNU General Public License as published by the   *
 * Free Software Foundation; either version 2 of the License, or (at you   *
 * option) any later version.                                              *
 *                                                                         *
 * This program is distributed in the hope that it will be useful, but     *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
 * General Public License for more details.                                *
 *                                                                         *
 * You should have received a copy of the GNU General Public License along *
 * with this program; if not, write to the Free Software Foundation, Inc., *
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA                  *
 *                                                                         *
 ***************************************************************************/

#ifndef QNOTIFY_CONTAINER_H
#define QNOTIFY_CONTAINER_H

#include <qpixmap.h>
#include <qpainter.h>
#include <qwidget.h>
#include <qbitmap.h>

class QSize;
class QPoint;
class QRect;
class QEvent;

/** @brief base class for QNotify widgets that need to draw their
 * background by their own */
class QNotifyContainer : public QWidget {
Q_OBJECT

public:
	/** @brief constructor */
	QNotifyContainer(QNotifyContainer *parent = 0, const char *name = 0, WFlags f = 0);

	/** @brief destructor */
	~QNotifyContainer();

	/** @brief the the rounding factor
	 *
	 * @param factor the rounding factor from 0 up to something like
	 *               10000
	 */
	void setRounding(int factor);


public slots:
	void exitTrue();

        void exitFalse();
	
protected:
	/** @brief get the current desktop geometry
	 *
	 * @return a QSize containing the desktop geometry
	 */
	static QSize desktopGeometry();

	/** @brief sets a mask for the given rect
	 *
	 * @param w the width
	 * @param h the hight
	 */
	void setOwnMask(int w, int h);

	/** @brief draws the background in a rectangle
	 *
	 * @param rect a rectangle to draw in
	 */
	void drawBackground(QRect rect);

	/** @brief inits a buffer for painting
	 *
	 * @param size the size to paint in
	 */
	void initBuffer(QSize size);

	/** @brief inits the mask for drawing
	 *
	 * @param size the size to init the mask
	 */
	void initMask(QSize size);

	/** @brief get the center position of a rect
	 *
	 * @param w1 the left most point in the rect
	 * @param h1 the top most point in the rect
	 * @param w2 the right most point in the rect
	 * @param h2 the bottom most point in the rect
	 */
	QPoint centerPosition(int w1, int h1, int w2, int h2);

	/** @brief buffer for painting @ref buffer */
	QPainter _bufferPainter;

	/** @brief the mask */
	QBitmap _mask;

	/** @brief painter for painting the mask */
	QPainter _maskPainter;

private:
	/** @brief get QEvents */
	bool event(QEvent * e);

	/** @brief pixmap to paint */
	QPixmap _buffer;
	
	/** @brief the rounding factor */
	int _rounding_factor;
};

#endif // QNOTIFY_CONTAINER_H
